#!/usr/bin/ksh
#############################################################################
#
# Licensed Materials - Property of IBM
#
# All Rights Reserved
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
#############################################################################
#
# NAME: installFixPak
#
#############################################################################

# Set PROGDIR to the directory where this file is located
CURDIR=`/usr/bin/pwd`
PROGDIR=`/usr/bin/dirname $0`
cd ${PROGDIR?}
PROGDIR=`/usr/bin/pwd`
cd ${CURDIR?}
CMD_SMINST="/usr/lib/instl/sm_inst"
PROGNAME=`/usr/bin/basename $0`       # Program name

# Before doing anything else, check if root is running the prog
if /usr/bin/id | /usr/bin/grep 'uid=0(' > /dev/null; then 
    :
else
    /usr/bin/echo "\n ${PROGNAME?}: You must be root to execute this program."
    /usr/bin/echo " Exiting.... "
    exit 1
fi

#-----------------------------------------------------------------------#
#               Start of function definitions
#-----------------------------------------------------------------------#

# To display the command syntax
syntax ()
{
    /usr/bin/echo ""
    /usr/bin/echo "Usage:  installFixPak [-a|-c]"
    /usr/bin/echo "        -a    All filesets will be applied only, not committed"
    /usr/bin/echo "        -c    All filesets will be committed after applying"
    /usr/bin/echo ""
    exit 1
}

# chkPreqLevel : determines the prereq level of IBM Directory if needed
chkPreqLevel ()
{
  RC=0

  return ${RC?}
}

# Default values for command line options
defaultopts()
{
    COMMIT=1     # default is applied
}

#-----------------------------------------------------------------------#
#                End of function definitions
#-----------------------------------------------------------------------#

#-----------------------------------------------------------------------#
#                             Main program
#-----------------------------------------------------------------------#

# Define default values for command-line options
defaultopts

# Process command-line options
case $# in
    0)
        :     # default case
        ;;
    1)
        while getopts :ac optchar ; do
            case ${optchar?} in
                a)  # Apply filesets only
                    COMMIT=1;;
                c)  # Commit filesets
                    COMMIT=0 ;;
                ?)  # Display help
                    syntax ;;
            esac
        done
        ;;
    *)
        syntax
        ;;
esac

chkPreqLevel
if [ $? -eq 0 ]; then

  if [ $COMMIT -eq "1" ]
  then
    echo "invoke installp to apply each fileset onto the system"
    cat ./UPDATES.list | while read ln
    do
        fn=`echo $ln | awk '{ print $1 }'`
        echo "fileset name is: $fn"
        installp -aXgd ./UPDATES $fn
    done

    #chmod 6550 `lslpp -f 'ldap.serv*' | grep runscript` > /dev/null 2>&1

    ##
    ## The readme filename is subject to be changed every shipping FixPak 
    ##
    FILEPATH=`lslpp -f 'ldap.client.rte' | grep ldapexop`
    if [ -f $FILEPATH ]
    then
        #echo $FILEPATH
        LDAP_INSTALL_DIR=`echo ${FILEPATH%%/bin/ldapexop}`
        #echo $LDAP_INSTALL_DIR
        cp -Rp ./FP510A-01Readme.pdf $LDAP_INSTALL_DIR/bin
    else
        ## Otherwise, copy readme file to the default ldap install path: /usr/ldap
        cp -Rp ./FP510A-01Readme.pdf /usr/ldap/bin
    fi

  else
    echo "invoke installp to commit the applied filesets"
    cat ./UPDATES.list | while read ln
    do
        fn=`echo $ln | awk '{ print $1 }'`
        echo "fileset name is: $fn"
        installp -c $fn
    done
  fi

else
    /usr/bin/echo "Aborting FixPak Install."
    exit 1
fi

